@@ -3,7 +3,6 @@ from typing import Any, Dict, Optional, Union
 import httpx
 
 from ...client import Client
-from ...models.login_info import LoginInfo
 from ...models.error import Error
 from ...models.token import Token
 from ...types import Response
@@ -11,7 +10,6 @@ from ...types import Response
 
 def _get_kwargs(
     *,
-    info: LoginInfo,
     client: Client,
 ) -> Dict[str, Any]:
     url = "{}/auth/login".format(client.base_url)
@@ -25,11 +23,12 @@ def _get_kwargs(
         "headers": headers,
         "cookies": cookies,
         "timeout": client.get_timeout(),
-        "json": info.to_dict(),
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[Union[Error, Token]]:
+def _parse_response(
+    *, response: httpx.Response
+) -> Optional[Union[Error, Token]]:
     if response.status_code == 200:
         response_200 = Token.from_dict(response.json())
 
@@ -41,7 +40,9 @@ def _parse_response(*, response: httpx.Response) -> Optional[Union[Error, Token]
     return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[Union[Error, Token]]:
+def _build_response(
+    *, response: httpx.Response
+) -> Response[Union[Error, Token]]:
     return Response(
         status_code=response.status_code,
         content=response.content,
@@ -53,7 +54,6 @@ def _build_response(*, response: httpx.Response) -> Response[Union[Error, Token]
 def sync_detailed(
     *,
     client: Client,
-    info: LoginInfo,
 ) -> Response[Union[Error, Token]]:
     """Log in a developer to nile
 
@@ -63,7 +63,6 @@ def sync_detailed(
 
     kwargs = _get_kwargs(
         client=client,
-        info=info,
     )
 
     response = httpx.request(
@@ -77,7 +76,6 @@ def sync_detailed(
 def sync(
     *,
     client: Client,
-    info: LoginInfo,
 ) -> Optional[Union[Error, Token]]:
     """Log in a developer to nile
 
@@ -87,14 +85,12 @@ def sync(
 
     return sync_detailed(
         client=client,
-        info=info,
     ).parsed
 
 
 async def asyncio_detailed(
     *,
     client: Client,
-    info: LoginInfo,
 ) -> Response[Union[Error, Token]]:
     """Log in a developer to nile
 
@@ -104,7 +100,6 @@ async def asyncio_detailed(
 
     kwargs = _get_kwargs(
         client=client,
-        info=info,
     )
 
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
@@ -116,7 +111,6 @@ async def asyncio_detailed(
 async def asyncio(
     *,
     client: Client,
-    info: LoginInfo,
 ) -> Optional[Union[Error, Token]]:
     """Log in a developer to nile
 
@@ -127,6 +121,5 @@ async def asyncio(
     return (
         await asyncio_detailed(
             client=client,
-            info=info,
         )
     ).parsed
