@@ -4,14 +4,12 @@ import httpx
 
 from ...client import Client
 from ...models.entity import Entity
-from ...models.create_entity_request import CreateEntityRequest
 from ...types import Response
 
 
 def _get_kwargs(
     workspace: str,
     *,
-    json_body: CreateEntityRequest,
     client: Client,
 ) -> Dict[str, Any]:
     url = "{}/workspaces/{workspace}/entities".format(
@@ -27,7 +25,6 @@ def _get_kwargs(
         "headers": headers,
         "cookies": cookies,
         "timeout": client.get_timeout(),
-        "json": json_body.to_dict(),
     }
 
 
@@ -51,10 +48,9 @@ def _build_response(*, response: httpx.Response) -> Response[Entity]:
 def sync_detailed(
     workspace: str,
     *,
-    json_body: CreateEntityRequest,
     client: Client,
 ) -> Response[Entity]:
-    """Create Entity
+    """Create an entity
 
     Args:
         workspace (str):
@@ -66,7 +62,6 @@ def sync_detailed(
     kwargs = _get_kwargs(
         workspace=workspace,
         client=client,
-        json_body=json_body,
     )
 
     response = httpx.request(
@@ -80,10 +75,9 @@ def sync_detailed(
 def sync(
     workspace: str,
     *,
-    json_body: CreateEntityRequest,
     client: Client,
 ) -> Optional[Entity]:
-    """Create Entity
+    """Create an entity
 
     Args:
         workspace (str):
@@ -95,17 +89,15 @@ def sync(
     return sync_detailed(
         workspace=workspace,
         client=client,
-        json_body=json_body,
     ).parsed
 
 
 async def asyncio_detailed(
     workspace: str,
     *,
-    json_body: CreateEntityRequest,
     client: Client,
 ) -> Response[Entity]:
-    """Create Entity
+    """Create an entity
 
     Args:
         workspace (str):
@@ -117,7 +109,6 @@ async def asyncio_detailed(
     kwargs = _get_kwargs(
         workspace=workspace,
         client=client,
-        json_body=json_body,
     )
 
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
@@ -129,10 +120,9 @@ async def asyncio_detailed(
 async def asyncio(
     workspace: str,
     *,
-    json_body: CreateEntityRequest,
     client: Client,
 ) -> Optional[Entity]:
-    """Create Entity
+    """Create an entity
 
     Args:
         workspace (str):
@@ -145,6 +135,5 @@ async def asyncio(
         await asyncio_detailed(
             workspace=workspace,
             client=client,
-            json_body=json_body,
         )
     ).parsed
